changeset 5106:2df44d5e75eb

(delete_window_event): New event kind.
author Richard M. Stallman <rms@gnu.org>
date Mon, 22 Nov 1993 04:04:46 +0000
parents 9b41ddf1b5f7
children 2a019dd8ed51
files src/termhooks.h
diffstat 1 files changed, 2 insertions(+), 1 deletions(-) [+]
line wrap: on
line diff
--- a/src/termhooks.h	Mon Nov 22 03:08:40 1993 +0000
+++ b/src/termhooks.h	Mon Nov 22 04:04:46 1993 +0000
@@ -241,7 +241,8 @@
 				   milliseconds) for the click.  */
   selection_request_event,	/* Another X client wants a selection from us.
 				   See `struct selection_event'.  */
-  selection_clear_event		/* Another X client cleared our selection.  */
+  selection_clear_event,	/* Another X client cleared our selection.  */
+  delete_window_event		/* An X client said "delete this window".  */
 };
 
 /* If a struct input_event has a kind which is selection_request_event